Module control_service_server

Module control_service_server 

Generated server implementations.

Structs

ControlServiceServer
Service for Worker runtime-to-application control communication. The Worker runtime hosts this service, and Worker applications connect to it.

Constants

SERVICE_NAME
Generated gRPC service name

Traits

ControlService
Generated trait containing gRPC methods that should be implemented for use with ControlServiceServer.