Module wait_until

Module wait_until 

Generated WaitUntil service client, server stub, and message types.

Modules

wait_until_service_client
Generated client implementations.
wait_until_service_server
Generated server implementations.

Structs

GetTaskCountRequest
Request to get current task count.
GetTaskCountResponse
NotifyDrainCompleteRequest
Request to notify that draining is complete.
NotifyDrainCompleteResponse
NotifyTaskRegisteredRequest
Request to notify the Worker runtime about a new registered task.
NotifyTaskRegisteredResponse
WaitForDrainSignalRequest
Request to wait for a drain signal from the Worker runtime.
WaitForDrainSignalResponse