pub struct WaitForDrainSignalRequest {
pub application_id: String,
pub timeout: Option<Duration>,
}Expand description
Request to wait for a drain signal from the Worker runtime.
Fields
application_id: StringUnique identifier for the application instance.
timeout: Option<Duration>Optional timeout for how long to wait for drain signal.