pub struct WaitUntilServiceClient<T> { /* private fields */ }Expand description
Service for coordinating wait_until tasks between a Worker application and its runtime.
Implementations
Sourceimpl<T> WaitUntilServiceClient<T>where
T: GrpcService<Body>,
T::Error: Into<StdError>,
T::ResponseBody: Body<Data = Bytes> + Send + 'static,
<T::ResponseBody as Body>::Error: Into<StdError> + Send,
impl<T> WaitUntilServiceClient<T>where
T: GrpcService<Body>,
T::Error: Into<StdError>,
T::ResponseBody: Body<Data = Bytes> + Send + 'static,
<T::ResponseBody as Body>::Error: Into<StdError> + Send,
pub fn new(inner: T) -> Self
pub fn with_origin(inner: T, origin: Uri) -> Self
pub fn with_interceptor<F>(
inner: T,
interceptor: F,
) -> WaitUntilServiceClient<InterceptedService<T, F>>where
F: Interceptor,
T::ResponseBody: Default,
T: Service<Request<Body>, Response = Response<<T as GrpcService<Body>>::ResponseBody>>,
<T as Service<Request<Body>>>::Error: Into<StdError> + Send + Sync,
Sourcepub fn send_compressed(self, encoding: CompressionEncoding) -> Self
pub fn send_compressed(self, encoding: CompressionEncoding) -> Self
Compress requests with the given encoding.
This requires the server to support it otherwise it might respond with an error.
Sourcepub fn accept_compressed(self, encoding: CompressionEncoding) -> Self
pub fn accept_compressed(self, encoding: CompressionEncoding) -> Self
Enable decompressing responses.
Sourcepub fn max_decoding_message_size(self, limit: usize) -> Self
pub fn max_decoding_message_size(self, limit: usize) -> Self
Limits the maximum size of a decoded message.
Default: 4MB
Sourcepub fn max_encoding_message_size(self, limit: usize) -> Self
pub fn max_encoding_message_size(self, limit: usize) -> Self
Limits the maximum size of an encoded message.
Default: usize::MAX
Sourcepub async fn notify_task_registered(
&mut self,
request: impl IntoRequest<NotifyTaskRegisteredRequest>,
) -> Result<Response<NotifyTaskRegisteredResponse>, Status>
pub async fn notify_task_registered( &mut self, request: impl IntoRequest<NotifyTaskRegisteredRequest>, ) -> Result<Response<NotifyTaskRegisteredResponse>, Status>
Application notifies the Worker runtime that it has registered a new task.
Sourcepub async fn wait_for_drain_signal(
&mut self,
request: impl IntoRequest<WaitForDrainSignalRequest>,
) -> Result<Response<WaitForDrainSignalResponse>, Status>
pub async fn wait_for_drain_signal( &mut self, request: impl IntoRequest<WaitForDrainSignalRequest>, ) -> Result<Response<WaitForDrainSignalResponse>, Status>
Application calls this to wait for a drain signal from the Worker runtime. This is a blocking call that returns when the Worker runtime decides it’s time to drain.
Sourcepub async fn notify_drain_complete(
&mut self,
request: impl IntoRequest<NotifyDrainCompleteRequest>,
) -> Result<Response<NotifyDrainCompleteResponse>, Status>
pub async fn notify_drain_complete( &mut self, request: impl IntoRequest<NotifyDrainCompleteRequest>, ) -> Result<Response<NotifyDrainCompleteResponse>, Status>
Application notifies the Worker runtime that it has completed draining all tasks.
Sourcepub async fn get_task_count(
&mut self,
request: impl IntoRequest<GetTaskCountRequest>,
) -> Result<Response<GetTaskCountResponse>, Status>
pub async fn get_task_count( &mut self, request: impl IntoRequest<GetTaskCountRequest>, ) -> Result<Response<GetTaskCountResponse>, Status>
Worker runtime can query how many tasks are currently registered (for monitoring).