Module wait_until_service_server

Module wait_until_service_server 

Generated server implementations.

Structs

WaitUntilServiceServer
Service for coordinating wait_until tasks between a Worker application and its runtime.

Constants

SERVICE_NAME
Generated gRPC service name

Traits

WaitUntilService
Generated trait containing gRPC methods that should be implemented for use with WaitUntilServiceServer.