The Worker app protocol between alien-worker-runtime and a Worker
application: task delivery, lifecycle, and waitUntil draining.
Generated clients and message types are always available. The Worker runtime
enables the server feature to host the Control and WaitUntil services.
Modules
- control
- Generated Control service client, server stub, and message types.
- wait_
until - Generated WaitUntil service client, server stub, and message types.