Generated server implementations.
Structs
- Control
Service Server - Service for Worker runtime-to-application control communication. The Worker runtime hosts this service, and Worker applications connect to it.
Constants
- SERVICE_
NAME - Generated gRPC service name
Traits
- Control
Service - Generated trait containing gRPC methods that should be implemented for use with ControlServiceServer.