Generated server implementations.
Structs
- Wait
Until Service Server - Service for coordinating wait_until tasks between a Worker application and its runtime.
Constants
- SERVICE_
NAME - Generated gRPC service name
Traits
- Wait
Until Service - Generated trait containing gRPC methods that should be implemented for use with WaitUntilServiceServer.